==> zio-aws-codebuild_3-5.17.102.7-sources.jar: zio/aws/codebuild/model/ListBuildsResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters.*
final case class ListBuildsResponse(
    ids: Option[Iterable[NonEmptyString]] = None,
    nextToken: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.ListBuildsResponse = {
    import ListBuildsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
      .builder()
      .optionallyWith(
        ids.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.ids)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.ListBuildsResponse.ReadOnly =
    zio.aws.codebuild.model.ListBuildsResponse.wrap(buildAwsValue())
}
object ListBuildsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.ListBuildsResponse =
      zio.aws.codebuild.model.ListBuildsResponse(
        ids.map(value => value),
        nextToken.map(value => value)
      )
    def ids: Option[List[NonEmptyString]]
    def nextToken: Option[String]
    def getIds: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("ids", ids)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
  ) extends zio.aws.codebuild.model.ListBuildsResponse.ReadOnly {
    override val ids: Option[List[NonEmptyString]] = scala
      .Option(impl.ids())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
  ): zio.aws.codebuild.model.ListBuildsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codebuild_3-5.17.295.12-sources.jar: zio/aws/codebuild/model/ListBuildsResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters.*
final case class ListBuildsResponse(
    ids: Optional[Iterable[NonEmptyString]] = Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.ListBuildsResponse = {
    import ListBuildsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
      .builder()
      .optionallyWith(
        ids.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.ids)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.ListBuildsResponse.ReadOnly =
    zio.aws.codebuild.model.ListBuildsResponse.wrap(buildAwsValue())
}
object ListBuildsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.ListBuildsResponse =
      zio.aws.codebuild.model.ListBuildsResponse(
        ids.map(value => value),
        nextToken.map(value => value)
      )
    def ids: Optional[List[NonEmptyString]]
    def nextToken: Optional[String]
    def getIds: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("ids", ids)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
  ) extends zio.aws.codebuild.model.ListBuildsResponse.ReadOnly {
    override val ids: Optional[List[NonEmptyString]] = zio.aws.core.internal
      .optionalFromNullable(impl.ids())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.ListBuildsResponse
  ): zio.aws.codebuild.model.ListBuildsResponse.ReadOnly = new Wrapper(impl)
}
